==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/deployment/impl/TerminatorServiceParameterSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.deployment.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceParameter;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceParameterSet;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceSet;
import io.ciera.tool.sql.ooaofooa.deployment.impl.TerminatorServiceParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.deployment.impl.TerminatorServiceSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;

import java.util.Arrays;
import java.util.List;


public class TerminatorServiceParameterSetImpl extends InstanceSet<TerminatorServiceParameterSet,TerminatorServiceParameter> implements TerminatorServiceParameterSet {

    // attributes
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setName( m_Name );
    }
    @Override
    public void setSvc_ID( UniqueId ref_Svc_ID ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setSvc_ID( ref_Svc_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setDescrip( m_Descrip );
    }
    @Override
    public void setTSParm_ID( UniqueId m_TSParm_ID ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setTSParm_ID( m_TSParm_ID );
    }
    @Override
    public void setPrevious_TSParm_ID( UniqueId ref_Previous_TSParm_ID ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setPrevious_TSParm_ID( ref_Previous_TSParm_ID );
    }
    @Override
    public void setDimensions( String m_Dimensions ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setDimensions( m_Dimensions );
    }
    @Override
    public void setBy_Ref( int m_By_Ref ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setBy_Ref( m_By_Ref );
    }


    // selections
    @Override
    public TerminatorServiceSet R1652_TerminatorService() throws XtumlException {
        TerminatorServiceSet terminatorserviceset = new TerminatorServiceSetImpl();
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceset.add( terminatorserviceparameter.R1652_TerminatorService() );
        return terminatorserviceset;
    }
    @Override
    public DataTypeSet R1653_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) datatypeset.add( terminatorserviceparameter.R1653_DataType() );
        return datatypeset;
    }
    @Override
    public TerminatorServiceParameterSet R1654_precedes_TerminatorServiceParameter() throws XtumlException {
        TerminatorServiceParameterSet terminatorserviceparameterset = new TerminatorServiceParameterSetImpl();
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameterset.add( terminatorserviceparameter.R1654_precedes_TerminatorServiceParameter() );
        return terminatorserviceparameterset;
    }
    @Override
    public TerminatorServiceParameterSet R1654_succeeds_TerminatorServiceParameter() throws XtumlException {
        TerminatorServiceParameterSet terminatorserviceparameterset = new TerminatorServiceParameterSetImpl();
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameterset.add( terminatorserviceparameter.R1654_succeeds_TerminatorServiceParameter() );
        return terminatorserviceparameterset;
    }
    @Override
    public DimensionsSet R1655_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) dimensionsset.addAll( terminatorserviceparameter.R1655_Dimensions() );
        return dimensionsset;
    }


    @Override
    public TerminatorServiceParameter nullElement() {
        return TerminatorServiceParameterImpl.EMPTY_TERMINATORSERVICEPARAMETER;
    }

    @Override
    public TerminatorServiceParameterSet emptySet() {
      return new TerminatorServiceParameterSetImpl();
    }

    @Override
    public TerminatorServiceParameterSet value() {
        return this;
    }

    @Override
    public List<TerminatorServiceParameter> elements() {
        TerminatorServiceParameter[] elements = toArray(new TerminatorServiceParameter[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/deployment/impl/TerminatorServiceParameterSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.deployment.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceParameter;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceParameterSet;
import io.ciera.tool.sql.ooaofooa.deployment.TerminatorServiceSet;
import io.ciera.tool.sql.ooaofooa.deployment.impl.TerminatorServiceParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.deployment.impl.TerminatorServiceSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class TerminatorServiceParameterSetImpl extends InstanceSet<TerminatorServiceParameterSet,TerminatorServiceParameter> implements TerminatorServiceParameterSet {

    public TerminatorServiceParameterSetImpl() {
    }

    public TerminatorServiceParameterSetImpl(Comparator<? super TerminatorServiceParameter> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setTSParm_ID( UniqueId m_TSParm_ID ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setTSParm_ID( m_TSParm_ID );
    }
    @Override
    public void setBy_Ref( int m_By_Ref ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setBy_Ref( m_By_Ref );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setDescrip( m_Descrip );
    }
    @Override
    public void setDimensions( String m_Dimensions ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setDimensions( m_Dimensions );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setName( m_Name );
    }
    @Override
    public void setPrevious_TSParm_ID( UniqueId ref_Previous_TSParm_ID ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setPrevious_TSParm_ID( ref_Previous_TSParm_ID );
    }
    @Override
    public void setSvc_ID( UniqueId ref_Svc_ID ) throws XtumlException {
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameter.setSvc_ID( ref_Svc_ID );
    }


    // selections
    @Override
    public TerminatorServiceSet R1652_TerminatorService() throws XtumlException {
        TerminatorServiceSet terminatorserviceset = new TerminatorServiceSetImpl();
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceset.add( terminatorserviceparameter.R1652_TerminatorService() );
        return terminatorserviceset;
    }
    @Override
    public DataTypeSet R1653_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) datatypeset.add( terminatorserviceparameter.R1653_DataType() );
        return datatypeset;
    }
    @Override
    public TerminatorServiceParameterSet R1654_precedes_TerminatorServiceParameter() throws XtumlException {
        TerminatorServiceParameterSet terminatorserviceparameterset = new TerminatorServiceParameterSetImpl();
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameterset.add( terminatorserviceparameter.R1654_precedes_TerminatorServiceParameter() );
        return terminatorserviceparameterset;
    }
    @Override
    public TerminatorServiceParameterSet R1654_succeeds_TerminatorServiceParameter() throws XtumlException {
        TerminatorServiceParameterSet terminatorserviceparameterset = new TerminatorServiceParameterSetImpl();
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) terminatorserviceparameterset.add( terminatorserviceparameter.R1654_succeeds_TerminatorServiceParameter() );
        return terminatorserviceparameterset;
    }
    @Override
    public DimensionsSet R1655_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( TerminatorServiceParameter terminatorserviceparameter : this ) dimensionsset.addAll( terminatorserviceparameter.R1655_Dimensions() );
        return dimensionsset;
    }


    @Override
    public TerminatorServiceParameter nullElement() {
        return TerminatorServiceParameterImpl.EMPTY_TERMINATORSERVICEPARAMETER;
    }

    @Override
    public TerminatorServiceParameterSet emptySet() {
      return new TerminatorServiceParameterSetImpl();
    }

    @Override
    public TerminatorServiceParameterSet emptySet(Comparator<? super TerminatorServiceParameter> comp) {
      return new TerminatorServiceParameterSetImpl(comp);
    }

    @Override
    public TerminatorServiceParameterSet value() {
        return this;
    }

    @Override
    public List<TerminatorServiceParameter> elements() {
        TerminatorServiceParameter[] elements = toArray(new TerminatorServiceParameter[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
